@@ -43,6 +43,8 @@ class ConfigFetcher(Thread):
                 try:
                     if key == "dataCollectionRules":
                         self.cfg.set("data_collection_rules", val)
+                    elif key == "rules":
+                        self.cfg.set("rules", val)
                     elif key == "filters":
                         self.cfg.set("filters", val)
                 except Exception:
