@@ -93,7 +93,8 @@ class ReportConsumer(Thread):
         if log_level == DETECTED:
             log = {key: log[key] for key in DETECTED_KEYS}
         else:
-            log["activeDataCollectionRules"] = matcher_result.active_rules
+            log["activeDataCollectionRules"] = matcher_result.active_data_collection_rules
+            log["activeRules"] = matcher_result.active_rules
 
             if log_level == RESTRICTED:
                 for key in RESTRICTED_DROP_KEYS:
