@@ -4,10 +4,12 @@
 # See the NOTICE for more information.
 
 import io
+import json
 import time
 import re
 import base64
 import platform
+import sys
 
 import pkg_resources
 import wrapt
@@ -41,7 +43,7 @@ def flag(flag_str):
     for flag in flag_str:
         attr_name = flag.upper()
         if not hasattr(re, attr_name):
-            raise ValueError(f"invalid flag {flag}")
+            raise ValueError("invalid flag {flag}".format(flag=flag))
         flags = flags | getattr(re, attr_name)
 
     return flags
@@ -125,3 +127,12 @@ class AsyncReadProxy(wrapt.ObjectProxy):
         else:
             self.__target__.write(data)
         return data
+
+
+if sys.version_info < (3, 6):
+    def json_loads(jsonval):
+        if isinstance(jsonval, bytes):
+            jsonval = jsonval.decode()
+        return json.loads(jsonval)
+else:
+    json_loads = json.loads
